pub struct InputKeyMaterial { /* private fields */ }Expand description
An input key material (IKM) is a secret random seed that is used to derive cryptographic keys.
In order to manage your IKMs, each one of them has an unique identifier. An IKM is also tight to a specific context in which it may be used. Keep in mind that an IKM is linked to a specific algorithm, as an expiration date and can be revoked.
This struct is exposed so you can display its informations when managing your IKMs using an InputKeyMaterialList. It it not meant to be used otherwise.
Implementations
Sourceimpl InputKeyMaterial
impl InputKeyMaterial
Sourcepub fn get_scheme(&self) -> Scheme
pub fn get_scheme(&self) -> Scheme
Returns the IKM’s scheme.
Sourcepub fn get_not_before(&self) -> SystemTime
pub fn get_not_before(&self) -> SystemTime
Returns the date before which the IKM must not be used to encrypt data.
Sourcepub fn get_not_after(&self) -> SystemTime
pub fn get_not_after(&self) -> SystemTime
Returns the date after which the IKM must not be used to encrypt data.
Sourcepub fn is_revoked(&self) -> bool
pub fn is_revoked(&self) -> bool
Check whether or not the IKM has been revoked.